@@ -12,11 +12,13 @@ import pandas as pd
 
 COMMAND_HELP = "The command to run and apply substitutions to"
 
+
 def _run_command(command, verbose):
     if verbose:
         print(command)
     sp.run(command, shell=True)
 
+
 def _run_sql_row(row, colnames, command, verbose):
     substitutions = {key: value for key, value in zip(colnames, row)}
     command = command.format(**substitutions)
@@ -58,11 +60,14 @@ def sqldo(args):
 
 
 def csvdo(args):
-    dframe = pd.read_csv(args.csv, delimiter=args.delimeter)
+    dframe = pd.read_csv(args.csv, delimiter=args.delimiter, lineterminator=args.lineterminator)
     with ThreadPoolExecutor(args.threads) as executor:
         return list(
             executor.map(
-                _run_df_row, (dframe.iloc[i] for i in range(len(dframe))), it.repeat(args.command), it.repeat(args.verbose)
+                _run_df_row,
+                (dframe.iloc[i] for i in range(len(dframe))),
+                it.repeat(args.command),
+                it.repeat(args.verbose),
             )
         )
 
@@ -77,7 +82,8 @@ def main():
     parser_csv = subparsers.add_parser("csv", help="csv input help")
     parser_csv.add_argument("command", help=COMMAND_HELP)
     parser_csv.add_argument("csv", help="Path to the csv file")
-    parser_csv.add_argument("--delimeter", default=",", help="The delimiter to use")
+    parser_csv.add_argument("--delimiter", default=",", help="The delimiter to use")
+    parser_csv.add_argument("--lineterminator", default="\n", help="The new line character to use")
     parser_csv.set_defaults(func=csvdo)
 
     parser_sql = subparsers.add_parser("sql", help="sql input help")
@@ -102,5 +108,6 @@ def main():
     args = parser.parse_args()
     args.func(args)
 
+
 if __name__ == "__main__":
     main()
